#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @time:2024/3/27 17:34
# Author:Zhang HongTao
# @File:nacos_connect.py

import json
import yaml
from nacos import NacosClient


class NacConnect(object):
    """Nacos连接类, 用于连接Nacos

    args:
        server_addresses: Nacos地址

        namespace: 命名空间

        username: 用户名

        password: 密码

        group_dict: 组合字典，
        eg:  {
                'group':{'t-dev':['project_name_1']},
                'username':'nacos',
                'password':'nacos',
                'server_addresses':'127.0.0.1:8080',
                'namespace':'t-dev'
        }

    """
    __instance = None  # 单例

    def __new__(cls, *args, **kwargs):
        """单例模式"""
        if not cls.__instance:
            cls.__instance = super(NacConnect, cls).__new__(cls)

        return cls.__instance

    def __init__(self, server_addresses, namespace, username, password, group, conf_type=None) -> None:
        """

        :param server_addresses: 地址
        :param namespace: 命名空间
        :param username: 用户名
        :param password: 密码
        :param group: 组合字典
        :param conf_type: 配置文件类型
        """
        self.CONF = {}
        self.client = NacosClient(server_addresses=server_addresses,
                                  namespace=namespace,
                                  username=username,
                                  password=password)
        self.group = group
        self.conf_type = conf_type

    def __call__(self, *args, **kwargs):
        self.main()
        return self.CONF

    def main(self):
        """初始化

        Returns:

        """

        COMMON_CONF = {}
        for group_name, data_ids in self.group.items():
            for data_id in data_ids:
                COMMON_CONF = self.get_and_watch(data_id, group_name, COMMON_CONF)

        self.CONF = COMMON_CONF

    def get_and_watch(self, data_id, group, pre_conf=None):
        """获取配置

        Args:
            data_id:
            group:
            pre_conf:

        Returns:

        """
        if pre_conf is None:
            pre_conf = {}
        conf_resolve = {}
        conf = self.client.get_config(data_id, group)  # 获取配置
        if conf is None:
            return pre_conf
        if self.conf_type == "json":
            conf_resolve = json.loads(conf)  # 转换为json
        elif self.conf_type == "yaml":
            conf_resolve = yaml.load(conf, Loader=yaml.FullLoader)
        else:
            conf_resolve = self.resolve_data(conf)
        pre_conf.update(conf_resolve)
        return pre_conf

    @staticmethod
    def resolve_data(conf_data):
        """解析配置

        Returns:

        """
        try:
            onf_resolve = json.loads(conf_data)  # 转换为json
        except json.JSONDecodeError:
            try:
                onf_resolve = yaml.load(conf_data, Loader=yaml.FullLoader)
            except yaml.YAMLError:
                onf_resolve = {}
        return onf_resolve





#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @time:2024/3/27 17:44
# Author:Zhang HongTao
# @File:read_conf_from_ini.py


import ast
import configparser
import os


class GetConfInfo:
    """获取配置文件中的信息
    """
    __instance = None

    def __new__(cls, *args, **kwargs):
        """单例模式

        :param args:
        :param kwargs:
        """
        if not cls.__instance:
            cls.__instance = super(GetConfInfo, cls).__new__(cls, *args, **kwargs)
        return cls.__instance

    def __init__(self):
        self.conf = configparser.RawConfigParser()
        path_file = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
        self.conf_path = os.path.join(os.getcwd(), "config", "conf.ini")
        self.conf.read(self.conf_path)
        log_env_path = os.path.join(path_file, 'logenv')
        self.field = self.get_field(log_env_path)

    @staticmethod
    def get_field(log_env_path):
        """根据log env记录的值，获取不同环境的配置参数

        :param log_env_path:
        :return:
        """
        field = "ENV-DEV"
        if not os.path.exists(log_env_path):
            # log env路径不存在，返回dev配置
            return field
        with open(log_env_path) as f:
            content_log = f.read()
            content_split = content_log.split('/')
        content_split = str(content_split).lower()
        if 'test' in content_split:
            field = "ENV-TEST"
        elif 'uat' in content_split:
            field = "ENV-UAT"
        elif 'prod' in content_split:
            field = "ENV-PROD"
        return field

    def get_conf_info(self, key):
        """获取key对应的配置信息

        :param key:
        :return:
        """
        conf_info = self.conf.get(self.field, key)
        return conf_info


if __name__ == '__main__':
    test_ins = GetConfInfo()
    res_t_1 = test_ins.get_conf_info("NACOS_CONFIG")
    res_t_2 = ast.literal_eval(res_t_1)
    print(res_t_1)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @time:2024/4/23 16:33
# Author:Zhang HongTao
# @File:cos_connect.py

from qcloud_cos import CosConfig
from qcloud_cos import CosS3Client


class CosConnect(object):
    """Cos连接类, 用于连接Cos

    args:
        secret_id: secret_id

        secret_key: secret_key

        region: 地域

        bucket: bucket

    """
    __instance = None  # 单例

    def __new__(cls, *args, **kwargs):
        """单例模式"""
        if not cls.__instance:
            cls.__instance = super(CosConnect, cls).__new__(cls)

        return cls.__instance

    def __init__(self, secret_id, secret_key, region="ap-shanghai") -> None:
        """

        :param secret_id: secret_id
        :param secret_key: secret_key
        :param region: 地域
        """
        self.secret_id = secret_id
        self.secret_key = secret_key
        self.region = region

        config = CosConfig(Region=region, SecretId=secret_id, SecretKey=secret_key)
        self.client = CosS3Client(config)




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @time:2023/4/14 18:12
# Author:Zhang HongTao
# @File:singleton.py

class SingletonMeta(type):
    """
    定义了一个名为SingletonMeta的元类，
    通过定义__call__方法来控制类的实例化过程，确保只创建一个实例。
    然后在定义类SingletonClass时，指定其元类为SingletonMeta，
    从而将SingletonClass变为单例模式
    """
    instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls.instances:
            cls.instances[cls] = super().__call__(*args, **kwargs)
        return cls.instances[cls]


# 示例
class SingletonClass(metaclass=SingletonMeta):
    pass



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @time:2024/3/27 17:02
# Author:Zhang HongTao
# @File:setup.py

from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name='common-tools-ai-bnq',
    version='0.1.7',
    packages=find_packages(),
    install_requires=[
        # 依赖项列表
        'structlog==23.1.0',
        'concurrent-log-handler==0.9.25',
        'nacos-sdk-python==0.1.12',
        'PyYAML==6.0.1',
        'cos-python-sdk-v5==1.9.28',
        'termcolor==2.4.0'
    ],
    # 其他元数据，如作者、描述等
    author='BNQ',
    description='Common tools of AI module for BNQ',
    long_description=long_description,
    long_description_content_type="text/markdown",  # 指明内容类型为markdown
)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @time:2024/3/27 17:34
# Author:Zhang HongTao
# @File:__init__.py.py

from .logger_record import LoggingRecord, LoggingRecordTimeRotation
from .nacos_connect import NacConnect
from .singleton import SingletonMeta
from .cos_connect import CosConnect

__all__ = ['LoggingRecord', 'LoggingRecordTimeRotation', 'NacConnect', 'SingletonMeta', 'CosConnect']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @time:2024/3/27 17:36
# Author:Zhang HongTao
# @File:logger_record.py

import logging
import logging.config
import logging.handlers
import os
import pathlib
import sys
import time

from structlog import configure, processors, stdlib
from termcolor import colored


class LoggingRecord(object):
    """日志记录类，用于记录运行中的信息

    """
    __instance = None  # 单例
    __filename = None  # 日志文件名

    def __new__(cls, log_dir=None, *args, **kwargs):
        """保证日志模块是单例模式"""
        if not cls.__instance:
            cls.__instance = super(LoggingRecord, cls).__new__(cls)
        __now_time = int(round(time.time()))
        __time_record = time.strftime("%Y%m%d", time.localtime(__now_time))
        cls.__filename = __time_record + "_BNQ_AI.log"
        return cls.__instance

    def __init__(self, max_bytes=20 * 1024 * 1024, backup_count=10, log_level=logging.INFO, log_dir=None):
        self.record_info = None
        self.logger = None
        self.log_record_path = log_dir  # 日志记录路径
        self.max_bytes = max_bytes  # 日志文件大小
        self.backup_count = backup_count  # 日志文件备份数量
        self.level = log_level  # 日志级别
        self.init_log()

    def init_log(self):
        """初始化log模块

        Returns:

        """
        if self.log_record_path is None:
            # 获取根目录路径，并创建日志文件夹
            # self.log_record_path = os.path.join(os.getcwd(), "logs")
            self.log_record_path = "/bnq/logs"

        pathlib.Path(self.log_record_path).mkdir(parents=True, exist_ok=True)
        log_filename = os.path.join(self.log_record_path, self.__filename)
        logging.config.dictConfig({
            "version": 1,
            "disable_existing_loggers": False,
            "formatters": {
                "default": {
                    "format": '%(asctime)s - %(levelname)s - %(name)s - %(message)s'
                },
                "console": {
                    "format": colored(f'[%(asctime)s][%(levelname)1.1s][%(process)d][%(name)s]', 'green') + colored(
                        f'(%(filename)s %(lineno)d)', 'yellow') + ': %(message)s'
                }
            },
            "handlers": {
                "console_handler": {
                    "class": "logging.StreamHandler",
                    "level": self.level,
                    "formatter": "console",
                    "stream": sys.stdout
                },
                "file_handler": {
                    "level": self.level,
                    "formatter": "default",
                    "class": "concurrent_log_handler.ConcurrentRotatingFileHandler",
                    "filename": log_filename,
                    "maxBytes": self.max_bytes,
                    "backupCount": self.backup_count,
                    "encoding": "UTF-8"
                },
            },
            "loggers": {
                "": {
                    "handlers": ["file_handler", "console_handler"],
                    "level": self.level
                }
            }
        })
        configure(
            context_class=dict,
            logger_factory=stdlib.LoggerFactory(),
            wrapper_class=stdlib.BoundLogger,
            processors=[
                stdlib.filter_by_level,
                stdlib.PositionalArgumentsFormatter(),
                processors.StackInfoRenderer(),
                processors.format_exc_info,
                processors.UnicodeDecoder(),
                stdlib.render_to_log_kwargs
            ]
        )
        self.logger = logging.getLogger("BNQ-AI")
        self.logger.level = self.level

    def debug(self, record_info):
        """debug级别的日志记录

        :param record_info:
        :return:
        """
        self.logger.debug(record_info)

    def info(self, record_info):
        """

        Args:
            record_info:

        Returns:

        """
        self.logger.info(record_info)

    def error(self, error_info, exc_info_=True):
        """

        Args:
            error_info:
            exc_info_:

        Returns:

        """
        self.logger.error(error_info, exc_info=exc_info_)

    def warning(self, warning_info):
        """

        Args:
            warning_info:

        Returns:

        """
        self.logger.warning(warning_info)

    def exception(self, exception_info):
        self.logger.exception(exception_info)


class LoggingRecordTimeRotation(object):
    """日志记录类，用于记录运行中的信息, 日志文件按时间切割

    """
    __instance = None  # 单例

    def __new__(cls, log_dir=None, *args, **kwargs):
        """保证日志模块是单例模式"""
        if not cls.__instance:
            cls.__instance = super(LoggingRecordTimeRotation, cls).__new__(cls)
        return cls.__instance

    def __init__(self, max_bytes=20 * 1024 * 1024, backup_count=10, log_level=logging.INFO, log_dir=None):
        self.record_info = None
        self.logger = None
        self.log_record_path = log_dir  # 日志记录路径
        self.max_bytes = max_bytes  # 日志文件大小
        self.backup_count = backup_count  # 日志文件备份数量
        self.level = log_level  # 日志级别
        self.init_log()

    def init_log(self):
        """初始化log模块

        Returns:

        """
        if self.log_record_path is None:
            # 获取根目录路径，并创建日志文件夹
            self.log_record_path = "/bnq/logs"

        pathlib.Path(self.log_record_path).mkdir(parents=True, exist_ok=True)
        log_filename = os.path.join(self.log_record_path, "access.log")
        logging.config.dictConfig({
            "version": 1,
            "disable_existing_loggers": False,
            "formatters": {
                "default": {
                    "format": '%(asctime)s - %(levelname)s - %(name)s - %(message)s'
                },
                "console": {
                    "format": colored(f'[%(asctime)s][%(levelname)1.1s][%(process)d][%(name)s]', 'green') + colored(
                        f'(%(filename)s %(lineno)d)', 'yellow') + ': %(message)s'
                }
            },
            "handlers": {
                "console_handler": {
                    "class": "logging.StreamHandler",
                    "level": self.level,
                    "formatter": "console",
                    "stream": sys.stdout
                },
                "file_handler": {
                    "level": self.level,
                    "formatter": "default",
                    "class": "concurrent_log_handler.ConcurrentTimedRotatingFileHandler",
                    "filename": log_filename,
                    "when": "midnight",
                    "maxBytes": self.max_bytes,
                    "backupCount": self.backup_count,
                    "encoding": "UTF-8"
                },
            },
            "loggers": {
                "": {
                    "handlers": ["file_handler", "console_handler"],
                    "level": self.level
                }
            }
        })
        self.logger = logging.getLogger("BNQ-AI")
        self.logger.level = self.level

    def debug(self, record_info):
        """debug级别的日志记录

        :param record_info:
        :return:
        """
        self.logger.debug(record_info)

    def info(self, record_info):
        """

        Args:
            record_info:

        Returns:

        """
        self.logger.info(record_info)

    def error(self, error_info, exc_info_=True):
        """

        Args:
            error_info:
            exc_info_:

        Returns:

        """
        self.logger.error(error_info, exc_info=exc_info_)

    def warning(self, warning_info):
        """

        Args:
            warning_info:

        Returns:

        """
        self.logger.warning(warning_info)

    def exception(self, exception_info):
        self.logger.exception(exception_info)


if __name__ == "__main__":

    # og_record_path = os.path.join(os.path.dirname(os.path.dirname(os.path.abspath(__file__))), "log")

    testLog = LoggingRecordTimeRotation(log_level=logging.DEBUG)
    for i in range(10):
        print(testLog, "testLog")
        testLog.debug(i)
        testLog.info("中文测试")
        testLog.error(i)
        testLog.warning(i)
        testLog.exception(i)
        # time.sleep(3)
